summaryrefslogtreecommitdiff
path: root/sbin
diff options
context:
space:
mode:
authorAngelos D. Keromytis <angelos@cvs.openbsd.org>1999-02-24 22:56:03 +0000
committerAngelos D. Keromytis <angelos@cvs.openbsd.org>1999-02-24 22:56:03 +0000
commitf2bb35389f8448ea5aa270a5a7324e7980287005 (patch)
treedfb8991acdd994e5338347d28da47bca7a474f6c /sbin
parentc3043a540a08aa456489eb35fc95d0c34257d27e (diff)
Grok PF_KEY.
Diffstat (limited to 'sbin')
-rw-r--r--sbin/route/route.c6
-rw-r--r--sbin/route/show.c14
2 files changed, 10 insertions, 10 deletions
diff --git a/sbin/route/route.c b/sbin/route/route.c
index 584311737ee..c61b0127393 100644
--- a/sbin/route/route.c
+++ b/sbin/route/route.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: route.c,v 1.29 1999/01/08 00:38:30 deraadt Exp $ */
+/* $OpenBSD: route.c,v 1.30 1999/02/24 22:56:01 angelos Exp $ */
/* $NetBSD: route.c,v 1.16 1996/04/15 18:27:05 cgd Exp $ */
/*
@@ -44,7 +44,7 @@ static char copyright[] =
#if 0
static char sccsid[] = "@(#)route.c 8.3 (Berkeley) 3/19/94";
#else
-static char rcsid[] = "$OpenBSD: route.c,v 1.29 1999/01/08 00:38:30 deraadt Exp $";
+static char rcsid[] = "$OpenBSD: route.c,v 1.30 1999/02/24 22:56:01 angelos Exp $";
#endif
#endif /* not lint */
@@ -258,7 +258,7 @@ flushroutes(argc, argv)
af = AF_ISO;
break;
case K_ENCAP:
- af = AF_ENCAP;
+ af = PF_KEY;
break;
case K_X25:
af = AF_CCITT;
diff --git a/sbin/route/show.c b/sbin/route/show.c
index 386ded5aa6e..40fa2419db2 100644
--- a/sbin/route/show.c
+++ b/sbin/route/show.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: show.c,v 1.7 1998/09/21 08:31:46 deraadt Exp $ */
+/* $OpenBSD: show.c,v 1.8 1999/02/24 22:56:02 angelos Exp $ */
/* $NetBSD: show.c,v 1.1 1996/11/15 18:01:41 gwr Exp $ */
/*
@@ -38,7 +38,7 @@
#if 0
static char sccsid[] = "from: @(#)route.c 8.3 (Berkeley) 3/9/94";
#else
-static char *rcsid = "$OpenBSD: show.c,v 1.7 1998/09/21 08:31:46 deraadt Exp $";
+static char *rcsid = "$OpenBSD: show.c,v 1.8 1999/02/24 22:56:02 angelos Exp $";
#endif
#endif /* not lint */
@@ -53,7 +53,7 @@ static char *rcsid = "$OpenBSD: show.c,v 1.7 1998/09/21 08:31:46 deraadt Exp $";
#include <net/route.h>
#include <netinet/in.h>
#include <netns/ns.h>
-#include <net/encap.h>
+#include <netinet/ip_ipsp.h>
#include <arpa/inet.h>
#include <sys/sysctl.h>
@@ -196,12 +196,12 @@ p_rtentry(rtm)
if (old_af != af) {
old_af = af;
pr_family(af);
- if (af != AF_ENCAP)
+ if (af != PF_KEY)
pr_rthdr();
else
pr_encaphdr();
}
- if (af == AF_ENCAP) {
+ if (af == PF_KEY) {
encap_print(rtm);
return;
}
@@ -219,7 +219,7 @@ p_rtentry(rtm)
}
/*
* Print header for AF_ENCAP entries.
*/
void
pr_encaphdr()
@@ -254,7 +254,7 @@ pr_family(af)
case AF_CCITT:
afname = "X.25";
break;
- case AF_ENCAP:
+ case PF_KEY:
afname = "IPsec";
break;
case AF_APPLETALK:
@@ -219,7 +219,7 @@ p_rtentry(rtm)
}
/*
- * Print header for AF_ENCAP entries.
+ * Print header for PF_KEY entries.
*/
void